pub struct VillagerType {
pub key: Identifier,
}Fields
key: IdentifierTrait Implementations
Sourceimpl Debug for VillagerType
impl Debug for VillagerType
impl Eq for VillagerType
Sourceimpl PartialEq for VillagerType
impl PartialEq for VillagerType
Sourceimpl RegistryEntry for VillagerType
impl RegistryEntry for VillagerType
Sourceimpl RegistryHolderSetEntry for VillagerType
impl RegistryHolderSetEntry for VillagerType
Sourceconst REGISTRY_NAME: &'static str = "villager type"
const REGISTRY_NAME: &'static str = "villager type"
Human-readable registry name used in codec errors.
Sourcefn holder_set_by_id(id: usize) -> Option<&'static Self>
fn holder_set_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn holder_set_by_key(key: &Identifier) -> Option<&'static Self>
fn holder_set_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourcefn holder_set_tag_exists(tag: &Identifier) -> bool
fn holder_set_tag_exists(tag: &Identifier) -> bool
Returns whether the registry contains this tag.
Sourcefn holder_set_tag_contains(entry: &'static Self, tag: &Identifier) -> bool
fn holder_set_tag_contains(entry: &'static Self, tag: &Identifier) -> bool
Returns whether an entry belongs to this tag.
Sourceimpl RegistryReferenceEntry for VillagerType
impl RegistryReferenceEntry for VillagerType
Sourceconst REGISTRY_NAME: &'static str = "villager type"
const REGISTRY_NAME: &'static str = "villager type"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.